
orderMenuGeneralFrame = {}
local orderMenuGeneralFrame_mt = Class(orderMenuGeneralFrame, TabbedMenuFrameElement)

orderMenuGeneralFrame.L10N_SYMBOL = {}

orderMenuGeneralFrame.CONTROLS = {
    GENERAL_CONTAINER = "generalContainer",
    HELP_BOX_TEXT = "generalHelpBoxText",
    COST_BOX_TEXT = "generalCostBoxText",
    HELP_BOX = "generalHelpBox",
    SET_TIP_FILLTYPE_CHANGE = "setTipFillTypeChange",
    SET_TIP_FILLTYPE_AMOUNT = "setTipFillTypeAmount",
    BUTTON_TIP_FILL_TYPE = "buttonTipFillType"
}


orderMenuGeneralFrame.TIP_TO_GROUND = {
    0,
    1000,
    10000,
    20000,
    30000,
    40000,
    50000,
    60000,
    70000,
    80000,
    90000,
    100000
}

function orderMenuGeneralFrame:new()
    local self = TabbedMenuFrameElement:new(nil, orderMenuGeneralFrame_mt)

    self.l10n = g_i18n
    self.printToLog = false

    self.allowCommandStatePrint = true

    self.fillTypeTitles = {}
    self.selectedIndexToFillTypeName = {}
    self.selectedIndex = {}
    self.selectedIndexPrice = {}


    self.pileFillTypeIndex = nil
    self.pileVolumeToTip = 0


    self:registerControls(orderMenuGeneralFrame.CONTROLS)

    return self
end

function orderMenuGeneralFrame:initialize(l10n, printToLog)
    self.l10n = l10n
    self.printToLog = printToLog

    local offText = l10n:getText("ui_off")
end

function orderMenuGeneralFrame:onFrameOpen()
    orderMenuGeneralFrame:superClass().onFrameOpen(self)

	self.uniqueUserId = g_currentMission.playerUserId
	self.isFarmManager = g_farmManager:getFarmByUserId(g_currentMission.playerUserId):isUserFarmManager(g_currentMission.playerUserId)
    local notServer = not self.isFarmManager	
    local disableCommand = true
    if g_currentMission:getIsServer() or g_currentMission.isMasterUser or self.isFarmManager then
        disableCommand = false
    end

    if self.isFarmManager then
        if #self.selectedIndexToFillTypeName == 0 then
            local i = 1
            local fillTypes = g_fillTypeManager:getFillTypes()
            for _, fillType in pairs (fillTypes) do
                if fillType.name ~= "TARP" and DensityMapHeightUtil.getCanTipToGround(fillType.index) then
                    self.fillTypeTitles[i] = fillType.title
                    self.selectedIndexToFillTypeName[i] = fillType.name
                    self.selectedIndex[i] = _
                    self.selectedIndexPrice[i] = fillType.pricePerLiter
                    i = i + 1
                end
            end
        end

        self.setTipFillTypeChange:setTexts(self.fillTypeTitles)
        self.setTipFillTypeChange:setState(1, true)
    else
        self.setTipFillTypeChange:setTexts({"Farmmanager Only!"})
    end

    self.setTipFillTypeAmount:setTexts(orderMenuGeneralFrame.TIP_TO_GROUND)
    self.setTipFillTypeAmount:setState(1, true)

    self.setTipFillTypeChange:setDisabled(notServer)
    self.setTipFillTypeAmount:setDisabled(notServer)
    self.buttonTipFillType:setDisabled(true)



end

function orderMenuGeneralFrame:onClickTipFillTypeChange(index)
    self.pileFillTypeName = self.selectedIndexToFillTypeName[index]
    self.pileFillTypeIndex = self.selectedIndex[index]
    self.pileFillTypePrice = self.selectedIndexPrice[index]

	self.costText = " "
	self.generalCostBoxText:setVisible(false)
	if self.isFarmManager then
		self.costText = self.l10n:getText("OM_calculatedCosts") .. self.l10n:formatMoney(math.floor(self.pileFillTypePrice*5*self.pileVolumeToTip))
		self.farmMoney = g_farmManager:getFarmByUserId(g_currentMission.playerUserId):getBalance()
		self.shit = self.pileFillTypePrice*5*self.pileVolumeToTip
		if self.shit > self.farmMoney then
			self.buttonTipFillType:setDisabled(true)
		else
			self.buttonTipFillType:setDisabled(false)
		end
		self.generalCostBoxText:setText(self.costText)
		self.generalCostBoxText:setVisible(true)
	end
end

function orderMenuGeneralFrame:onClickTipFillTypeAmount(index)
    self.pileVolumeToTip = orderMenuGeneralFrame.TIP_TO_GROUND[index]
    self.buttonTipFillType:setDisabled(index == 1)

	self.costText = " "
	self.generalCostBoxText:setVisible(false)
	local difficultyFactor = EconomyManager.getPriceMultiplier()

	if self.isFarmManager then
		self.costText = self.l10n:getText("OM_calculatedCosts") .. self.l10n:formatMoney(math.floor(self.pileFillTypePrice*5*self.pileVolumeToTip))
		self.farmMoney = g_farmManager:getFarmByUserId(g_currentMission.playerUserId):getBalance()
		self.shit = self.pileFillTypePrice*5*self.pileVolumeToTip
		if self.shit > self.farmMoney then
			self.buttonTipFillType:setDisabled(true)
		else
			self.buttonTipFillType:setDisabled(false)
		end
		self.generalCostBoxText:setText(self.costText)
		self.generalCostBoxText:setVisible(true)
	end
end

function orderMenuGeneralFrame:onClickTipFillType()
    if self.pileVolumeToTip > 0 then
        if self.pileFillTypeName ~= nil then
			self.FarmID = FarmManager.SPECTATOR_FARM_ID
			if g_currentMission:getIsClient() and g_currentMission.player ~= nil then
				self.x1,self.y1,self.z1 = getWorldTranslation(g_currentMission.player.rootNode);
				g_currentMission.player:moveRootNodeToAbsolute(self.x1, self.y1+3, self.z1);
				self.FarmID = g_currentMission.player.farmId
			end
			if self.FarmID == FarmManager.SPECTATOR_FARM_ID then
				return
			end
			
			local delta = self.pileVolumeToTip;
			local fillType = self.pileFillTypeIndex;
			local xzRndm = ((math.random(1, 20))-10)/10;
			local xOffset = math.max(math.min(xzRndm, 0.3), -0.3);
			local zOffset = math.max(math.min(xzRndm, 0.8), -0.1);
			local ex = self.x1 + 2;
			local ey = self.y1 + 0;
			local ez = self.z1 + 2;
			local innerRadius = 0;
			local levelerNode = 1;
			
			droppedLevel = 0
			if g_currentMission:getIsServer() then
				droppedLevel, lineOffset = DensityMapHeightUtil.tipToGroundAroundLine(nil, delta, fillType, self.x1, self.y1, self.z1, ex, ey, ez, 0, 30, 1, false, nil)
			else
				g_client:getServerConnection():sendEvent(orderMenuSiloCheatEvent:new(fillType, delta, self.FarmID, self.x1, self.y1, self.z1, ex, ey, ez, self.pileFillTypePrice))
				droppedLevel = 0
			end
			
			self.deliveredGoods = math.floor(droppedLevel)
			if self.deliveredGoods > 0 then
				self.deliveredCosts = math.floor(self.pileFillTypePrice*5*self.deliveredGoods);
				g_currentMission:addMoney(-self.deliveredCosts, self.FarmID, MoneyType.OTHER, true, true);
				self.allowCommandStatePrint = true
				self:printCommandState(self.l10n:getText("OM_tipped") .. tostring(self.deliveredGoods))
			else
				self.allowCommandStatePrint = true
				self:printCommandState(self.l10n:getText("OM_tipped") .. tostring(self.deliveredGoods))
			end
        end
    end
end


function orderMenuGeneralFrame:onToolTipBoxTextChanged(toolTipBox)
    local showText = (toolTipBox.text ~= nil and toolTipBox.text ~= "")
    self.generalHelpBox:setVisible(showText)
end

function orderMenuGeneralFrame:getMainElementSize()
    return self.generalContainer.size
end

function orderMenuGeneralFrame:getMainElementPosition()
    return self.generalContainer.absPosition
end

function orderMenuGeneralFrame:printCommandState(text)
    if self.allowCommandStatePrint and (text ~= nil and text ~= "") then

        self.generalHelpBoxText:setText(text)
        self.generalHelpBox:setVisible(true)

    end
end
function orderMenuGeneralFrame:dropIt(fillTypeX, deltaX, farmID, x1, y1, z1, x2, y2, z2, pileFillTypePrice)
	local droppedLevel2 = 0
	self.droppedLevel2 = 0
    droppedLevel2, lineOffset = DensityMapHeightUtil.tipToGroundAroundLine(nil, deltaX, fillTypeX, x1, y1, z1, x2, y2, z2, 0, 30, 1, false, nil)
	self.deliveredGoods = math.floor(droppedLevel2)
	if self.deliveredGoods > 0 then
		self.deliveredCosts = math.floor(pileFillTypePrice*5*self.deliveredGoods);
		g_currentMission:addMoney(-self.deliveredCosts, farmID, MoneyType.OTHER, true, true);
	end
	self.droppedLevel2 = droppedLevel2
	return droppedLevel2
end