
orderMenuTabbedMenu = {}
local orderMenuTabbedMenu_mt = Class(orderMenuTabbedMenu, TabbedMenu)

local function predicate()
    return true
end

orderMenuTabbedMenu.CONTROLS = {
    BACKGROUND = "inGameBackgroundElement",
    PAGE_GENERAL = "pageGeneral"
}

orderMenuTabbedMenu.TAB_UV = {
    GENERAL = {844, 144, 65, 65},
}

orderMenuTabbedMenu.BUTTONS = {
    BACK = "button_back"
}

orderMenuTabbedMenu.PAGE_ID_TO_TITLE = {
    [1] = "OM_generalPage",
}

function orderMenuTabbedMenu:new(target, messageCenter, l10n, inputManager, printToLog)
    local self = TabbedMenu:new(target, orderMenuTabbedMenu_mt, messageCenter, l10n, inputManager)

    self.backgroundActive = true
    self.performBackgroundBlur = true

    self.pageSetupIndex = 1
    self.allowPageSetup = false

    self.l10n = l10n
    self.printToLog = printToLog

    self:registerControls(orderMenuTabbedMenu.CONTROLS)

    return self
end

function orderMenuTabbedMenu:onOpen(element)
    orderMenuTabbedMenu:superClass().onOpen(self, element)

    self.backgroundActive = true
    self.inGameBackgroundElement:setVisible(true)
end

function orderMenuTabbedMenu:onGuiSetupFinished()
    orderMenuTabbedMenu:superClass().onGuiSetupFinished(self)

    self.pageSetupIndex = 1
    self.allowPageSetup = true

    self:setupPage(self.pageGeneral, orderMenuTabbedMenu.TAB_UV.GENERAL)

    self.allowPageSetup = false
end

function orderMenuTabbedMenu:setupPage(page, icon, iconFilename)
    if self.allowPageSetup then
        if iconFilename == nil then
            iconFilename = g_baseUIFilename
        end

        page:initialize(self.l10n, self.printToLog)

        self:registerPage(page, self.pageSetupIndex, predicate)

        local normalizedUVs = getNormalizedUVs(icon)
        self:addPageTab(page, iconFilename, normalizedUVs)

        self.pageSetupIndex = self.pageSetupIndex + 1
    end
end

function orderMenuTabbedMenu:setupMenuButtonInfo()
    local clickBackCallback = self:makeSelfCallback(self.clickBackCallback)
    local resetCallback = self:makeSelfCallback(self.clickResetCallback)
    local clickRemoveBackground = self:makeSelfCallback(self.clickRemoveBackground)

    self.defaultMenuButtonInfo = {
        {inputAction = InputAction.MENU_BACK, text = self.l10n:getText(orderMenuTabbedMenu.BUTTONS.BACK), callback = clickBackCallback}
    }

    self.defaultMenuButtonInfoByActions[InputAction.MENU_BACK] = self.defaultMenuButtonInfo[1]

    self.defaultButtonActionCallbacks = {
        [InputAction.MENU_BACK] = clickBackCallback
    }
end


function orderMenuTabbedMenu:onPageClicked(oldPage)
end
